@@ -13,7 +13,7 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 
 from toolspy.datetime_tools import n_days_ago
 
-from .utils.datetime_utils import tz_converted_date
+from .utils.datetime_utils import tz_converted_date, tz_convert
 
 
 class SqlaQueryBuilder(object):
@@ -30,14 +30,16 @@ class SqlaQueryBuilder(object):
             self.session = scoped_session(self.sessionmaker)
 
     @contextmanager
-    def scoped_session(self):
+    def scoped_session(self, commit=False):
         """Provide a transactional scope around a series of operations."""
         session = self.sessionmaker()
         try:
             yield session
-            session.commit()
+            if commit:
+                session.commit()
         except:
-            session.rollback()
+            if commit:
+                session.rollback()
             raise
         finally:
             session.close()
@@ -50,6 +52,10 @@ class SqlaQueryBuilder(object):
         return tz_converted_date(
             datetime_col, self.timedelta_mins_from_utc)
 
+    def local_tz_convert(self, datetime_col):
+        return tz_convert(
+            datetime_col, self.timedelta_mins_from_utc)
+
     def local_n_days_ago(self, n):
         return n_days_ago(
             n, timedelta_mins_from_utc=self.timedelta_mins_from_utc)
